const fs = require('fs');
const packageJson = require('../package.json');
const output = {
    paths: ['./dist', './docs'],
    file: 'meta.json'
};
const componentsDir = './src/components';
const fileData = path => fs.readFileSync(path, { encoding: 'utf8' });
const exportVars = (src, simpleValues = false) => {
    const r = '^@(.+?):\\s*(.+);( // (.+))?';
    const fm = src.match(new RegExp(r, 'gm'));
    return fm
        ? fm.reduce((obj, v) => {
              const m = v.match(new RegExp(r));
              const [_, key, value, d, descr] = m;
              if (!simpleValues || (simpleValues && !value.includes('@'))) {
                  obj[key] = { value, descr };
              }
              return obj;
          }, {})
        : [];
};
const exportHooks = src => {
    const r = /((\/\*\*([\W\w]+)\*\/)([\s\S]+?))?\.(hook-(.+))\s+{/gm;
    const fm = src.matchAll(r);
    return fm
        ? [...fm].reduce((obj, [_, m1, descr, m2, m3, hook]) => {
              obj[hook] = { descr };
              return obj;
          }, {})
        : [];
};

const vars = {
    version: packageJson.version,
    core: { vars: exportVars(fileData('./src/_params.less')) },
    components: {}
};
fs.readdirSync(componentsDir).forEach(file => {
    const src = fileData(`${componentsDir}/${file}`);
    const name = file.split('.').shift();
    vars.components[name] = {
        vars: exportVars(src),
        hooks: exportHooks(src)
    };
});

output.paths.forEach(path => {
    fs.writeFileSync(`${path}/${output.file}`, JSON.stringify(vars));
});
